@@ -20,7 +20,7 @@ additive <- function(base = NULL, frontier = NULL, noutput = 1){
   front.Y <- t(frontier[, 1:s])
   front.X <- t(frontier[, (s+1):(s+m)])
   base.Y <- t(base[, 1:s])
-  base.X <- t(frontier[, (s+1):(s+m)])
+  base.X <- t(base[, (s+1):(s+m)])
 
 
   front.mat <- rbind(front.X, front.Y, 1)
