@@ -20,7 +20,7 @@ sbm.tone <- function(base= NULL, frontier = NULL, noutput = 1){
   front.Y <- t(frontier[, 1:s])
   front.X <- t(frontier[, (s+1):(s+m)])
   base.Y <- t(base[, 1:s])
-  base.X <- t(frontier[, (s+1):(s+m)])
+  base.X <- t(base[, (s+1):(s+m)])
 
   re <- data.frame(matrix(0, nrow = n, ncol = 1 + nf + m + s))
   names(re) <- c("eff",
